// -*- Mode: C++; -*-

#include "kmysqladmin/helpers/stringlist.h"

class CScriptSplit
{
    stringlist*target_list;
    std::string*input_string;
    
    int remove_empty_lines();
    int convert_tabs();
    int remove_comments();
    int remove_spaces();
    int make_lines();
    int remove_lastspaces();

public:
    CScriptSplit(stringlist*target,std::string*input);
    ~CScriptSplit();
    int convert();
};
